@@ -148,11 +148,19 @@ char *fallback_resources[] = {
                               "The above mappings are *always* active in ViewOnly mode, unless you set the\\n"
                               "Escape Keys value to 'never'.\\n"
                               "\\n"
-                              "If the Escape Keys value below is set to 'default' then a default list of\\n"
-                              "of modifier keys is used.  For Unix it is: Alt_L,Super_L and for MacOSX it\\n"
-                              "is Control_L,Meta_L.  Note: the Super_L key usually has a Windows(TM) Flag\\n"
-                              "on it.  Also note the _L and _R mean the key is on the LEFT or RIGHT side\\n"
-                              "of the keyboard.\\n"
+                              "x11vnc -appshare hot-keys:  x11vnc has a simple application sharing mode\\n"
+                              "that enables the viewer-side to move, resize, or raise the remote toplevel\\n"
+                              "windows.  To enable it, hold down Shift + the Escape Keys and press these:\\n"
+                              "\\n"
+                              "   Arrow keys:              move the remote window around in its desktop.\\n"
+                              "   PageUp/PageDn/Home/End:  resize the remote window.\\n"
+                              "   +/-                      raise or lower the remote window.\\n"
+                              "   M or Button1 move win to local position;  D or Button3: delete remote win.\\n"
+                              "\\n"
+                              "If the Escape Keys value below is set to 'default' then a fixed list of\\n"
+                              "modifier keys is used.  For Unix it is: Alt_L,Super_L and for MacOSX it is\\n"
+                              "Control_L,Meta_L.  Note: the Super_L key usually has a Windows(TM) Flag.\\n"
+                              "Also note the _L and _R mean the key is on the LEFT or RIGHT side of keyboard.\\n"
                               "\\n"
                               "On Unix   the default is Alt and Windows keys on Left side of keyboard.\\n"
                               "On MacOSX the default is Control and Command keys on Left side of keyboard.\\n"
@@ -167,7 +175,7 @@ char *fallback_resources[] = {
                               "\\n"
                               "Current Escape Keys Value:",
   "*escapeDialog.dialog.value:",
-  "*escapeDialog.dialog.value.width: 275",
+  "*escapeDialog.dialog.value.width: 280",
   "*escapeDialog.dialog.value.translations: #override\\n\
      <KeyRelease>Return: EscapeDialogDone()",
 
@@ -888,6 +896,12 @@ static XtResource appDataResourceList[] = {
 #endif
 #endif
 
+  {"noipv4", "noipv4", XtRBool, sizeof(Bool),
+   XtOffsetOf(AppData, noipv4), XtRImmediate, (XtPointer) False},
+
+  {"noipv6", "noipv6", XtRBool, sizeof(Bool),
+   XtOffsetOf(AppData, noipv6), XtRImmediate, (XtPointer) False},
+
   {"sendClipboard", "SendClipboard", XtRBool, sizeof(Bool),
    XtOffsetOf(AppData, sendClipboard), XtRImmediate, (XtPointer) False},
 
@@ -897,6 +911,9 @@ static XtResource appDataResourceList[] = {
   {"recvText", "RecvText", XtRString, sizeof(String),
    XtOffsetOf(AppData, recvText), XtRImmediate, (XtPointer) 0},
 
+  {"appShare", "AppShare", XtRBool, sizeof(Bool),
+   XtOffsetOf(AppData, appShare), XtRImmediate, (XtPointer) False},
+
   {"escapeKeys", "EscapeKeys", XtRString, sizeof(String),
    XtOffsetOf(AppData, escapeKeys), XtRImmediate, (XtPointer) 0},
 
@@ -967,12 +984,15 @@ XrmOptionDescRec cmdLineOptions[] = {
   {"-termchat",      "*termChat",           XrmoptionNoArg,  "True"},
   {"-chatonly",      "*chatOnly",           XrmoptionNoArg,  "True"},
   {"-scale",         "*scale",              XrmoptionSepArg, 0},
+  {"-appshare",      "*appShare",           XrmoptionNoArg,  "True"},
   {"-escape",        "*escapeKeys",         XrmoptionSepArg, 0},
   {"-sendclipboard", "*sendClipboard",      XrmoptionNoArg,  "True"},
   {"-sendalways",    "*sendAlways",         XrmoptionNoArg,  "True"},
   {"-recvtext",      "*recvText",           XrmoptionSepArg, 0},
   {"-pipeline",      "*pipelineUpdates",    XrmoptionNoArg,  "True"},
-  {"-nopipeline",    "*pipelineUpdates",    XrmoptionNoArg,  "False"}
+  {"-nopipeline",    "*pipelineUpdates",    XrmoptionNoArg,  "False"},
+  {"-noipv4",        "*noipv4",             XrmoptionNoArg,  "True"},
+  {"-noipv6",        "*noipv6",             XrmoptionNoArg,  "True"}
 };
 
 int numCmdLineOptions = XtNumber(cmdLineOptions);
@@ -1389,6 +1409,10 @@ usage(void)
 	  "                    specify as many as you need on the command line.  For\n"
 	  "                    example, -env SSVNC_MULTIPLE_LISTEN=MAX:5 -env EDITOR=vi\n"
 	  "\n"
+	  "     -noipv6        Disable all IPv6 sockets.  Same as VNCVIEWER_NO_IPV6=1.\n"
+	  "\n"
+	  "     -noipv4        Disable all IPv4 sockets.  Same as VNCVIEWER_NO_IPV4=1.\n"
+	  "\n"
 	  "     -printres      Print out the Ssvnc X resources (appdefaults) and then exit\n"  
 	  "                    You can save them to a file and customize them (e.g. the\n"  
 	  "                    keybindings and Popup menu)  Then point to the file via\n"  
@@ -1399,6 +1423,18 @@ usage(void)
 	  "                    framebuffer update coming in.  Helps 'pipeline' the updates.\n"
 	  "                    This is currently the default, use -nopipeline to disable.\n"
 	  "\n"
+	  "     -appshare      Enable features for use with x11vnc's -appshare mode where\n"
+	  "                    instead of sharing the full desktop only the application's\n"
+	  "                    windows are shared.  Viewer multilisten mode is used to\n"
+	  "                    create the multiple windows: -multilisten is implied.\n"
+	  "                    See 'x11vnc -appshare -help' more information on the mode.\n"
+	  "\n"
+	  "                    Features enabled in the viewer under -appshare are:\n"
+	  "                    Minimum extra text in the title, auto -ycrop is disabled,\n"
+	  "                    x11vnc -remote_prefix X11VNC_APPSHARE_CMD: message channel,\n"
+	  "                    x11vnc initial window position hints.  See also Escape Keys\n"
+	  "                    below for additional key and mouse bindings.\n"
+	  "\n"
 	  "     -escape str    This sets the 'Escape Keys' modifier sequence and enables\n"
 	  "                    escape keys mode.  When the modifier keys escape sequence\n"
 	  "                    is held down, the next keystroke is interpreted locally\n"
@@ -1512,12 +1548,12 @@ usage(void)
  * not already processed by XtVaAppInitialize().  It sets vncServerHost and
  * vncServerPort and all the fields in appData.
  */
+extern int saw_appshare;
 
 void
 GetArgsAndResources(int argc, char **argv)
 {
-	int i;
-	char *vncServerName, *colonPos;
+	char *vncServerName = NULL, *colonPos, *bracketPos;
 	int len, portOffset;
 	int disp;
 
@@ -1595,6 +1631,12 @@ GetArgsAndResources(int argc, char **argv)
 			appData.escapeKeys = strdup(getenv("VNCVIEWER_ESCAPE"));
 		}
 	}
+	if (saw_appshare) {
+		appData.appShare = True;
+	}
+	if (appData.appShare && appData.escapeKeys == NULL) {
+		appData.escapeKeys = strdup("default");
+	}
 	if (appData.escapeKeys != NULL) {
 		appData.escapeActive = True;
 	}
@@ -1620,6 +1662,13 @@ GetArgsAndResources(int argc, char **argv)
 		appData.pipelineUpdates = False;
 	}
 
+	if (getenv("VNCVIEWER_NO_IPV4")) {
+		appData.noipv4 = True;
+	}
+	if (getenv("VNCVIEWER_NO_IPV6")) {
+		appData.noipv6 = True;
+	}
+
 	if (appData.useBGR233 && appData.useBGR565) {
 		appData.useBGR233 = 0;
 	}
@@ -1698,7 +1747,8 @@ GetArgsAndResources(int argc, char **argv)
 		exit(1);
 	}
 
-	colonPos = strchr(vncServerName, ':');
+	colonPos = strrchr(vncServerName, ':');
+	bracketPos = strrchr(vncServerName, ']');
 	if (strstr(vncServerName, "exec=") == vncServerName) {
 		/* special exec-external-command case */
 		strcpy(vncServerHost, vncServerName);
@@ -1711,7 +1761,13 @@ GetArgsAndResources(int argc, char **argv)
 		/* No colon -- use default port number */
 		strcpy(vncServerHost, vncServerName);
 		vncServerPort = SERVER_PORT_OFFSET;
+	} else if (bracketPos != NULL && colonPos < bracketPos) {
+		strcpy(vncServerHost, vncServerName);
+		vncServerPort = SERVER_PORT_OFFSET;
 	} else {
+		if (colonPos > vncServerName && *(colonPos - 1) == ':') {
+			colonPos--;
+		}
 		memcpy(vncServerHost, vncServerName, colonPos - vncServerName);
 		vncServerHost[colonPos - vncServerName] = '\0';
 		len = strlen(colonPos + 1);
@@ -1722,7 +1778,7 @@ GetArgsAndResources(int argc, char **argv)
 			len--;
 			portOffset = 0;
 		}
-		if (!len || strspn(colonPos + 1, "0123456789") != len) {
+		if (!len || strspn(colonPos + 1, "0123456789") != (size_t) len) {
 			usage();
 		}
 #if 0
